==> kadu_1.0.orig.tar.bz2: kadu-1.0/kadu-core/plugin/plugin-conflict-resolver.h <==
/*
 * %kadu copyright begin%
 * Copyright 2009 Wojciech Treter (juzefwt@gmail.com)
 * Copyright 2012 Piotr Dąbrowski (ultr@ultr.pl)
 * Copyright 2004 Adrian Smarzewski (adrian@kadu.net)
 * Copyright 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
 * Copyright 2012 Bartosz Brachaczek (b.brachaczek@gmail.com)
 * Copyright 2004, 2006 Marcin Ślusarz (joi@kadu.net)
 * %kadu copyright end%
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of
 * the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */

#pragma once

#include "exports.h"

#include <set>
#include <QtCore/QObject>
#include <QtCore/QPointer>

class PluginDependencyHandler;

class KADUAPI PluginConflictResolver : public QObject
{
	Q_OBJECT

public:
	explicit PluginConflictResolver(QObject *parent = nullptr);
	virtual ~PluginConflictResolver();

	void setPluginDependencyHandler(PluginDependencyHandler *pluginDependencyHandler);

	std::set<QString> conflictingPlugins(const std::set<QString> &activePluginSet, const QString &pluginName);

private:
	QPointer<PluginDependencyHandler> m_pluginDependencyHandler;

};

==> kadu_3.0~rc1.orig.tar.bz2: kadu-3.0-rc1/kadu-core/plugin/plugin-conflict-resolver.h <==
/*
 * %kadu copyright begin%
 * Copyright 2014 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
 * %kadu copyright end%
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of
 * the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */

#pragma once

#include "exports.h"

#include <QtCore/QObject>
#include <QtCore/QPointer>
#include <injeqt/injeqt.h>
#include <set>

class PluginDependencyHandler;

class KADUAPI PluginConflictResolver : public QObject
{
	Q_OBJECT

public:
	Q_INVOKABLE explicit PluginConflictResolver(QObject *parent = nullptr);
	virtual ~PluginConflictResolver();

	std::set<QString> conflictingPlugins(const std::set<QString> &activePluginSet, const QString &pluginName);

private:
	QPointer<PluginDependencyHandler> m_pluginDependencyHandler;

public slots: // TODO: make private, public only because of tests, should be done by injector
	INJEQT_SETTER void setPluginDependencyHandler(PluginDependencyHandler *pluginDependencyHandler);

};
